use utf8;
package ExpenseTracker::Models;
{
  $ExpenseTracker::Models::VERSION = '0.005';
}
{
  $ExpenseTracker::Models::VERSION = '0.005';
}

# Created by DBIx::Class::Schema::Loader
# DO NOT MODIFY THE FIRST PART OF THIS FILE

use strict;
use warnings;

use base 'DBIx::Class::Schema';

__PACKAGE__->load_namespaces;


# Created by DBIx::Class::Schema::Loader v0.07017 @ 2012-07-08 11:25:25
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:ubhSbC7TLkFYO9posDuqWw


# You can replace this text with custom code or comments, and it will be preserved on regeneration

1;
